==> commons-io-2.13.0-src.tar.gz: commons-io-2.13.0-src/src/test/java/org/apache/commons/io/output/ClosedOutputStreamTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.io.output;

import static org.junit.jupiter.api.Assertions.assertThrows;

import java.io.IOException;

import org.junit.jupiter.api.Test;

/**
 * Tests {@link ClosedOutputStream}.
 */
public class ClosedOutputStreamTest {

    /**
     * Test the {@code flush()} method.
     */
    @Test
    public void testFlush() throws IOException {
        try (ClosedOutputStream cos = new ClosedOutputStream()) {
            assertThrows(IOException.class, () -> cos.flush());
        }
    }

    /**
     * Test the {@code write(b)} method.
     */
    @Test
    public void testWrite() throws IOException {
        try (ClosedOutputStream cos = new ClosedOutputStream()) {
            assertThrows(IOException.class, () -> cos.write('x'));
        }
    }

}

==> commons-io-2.21.0-src.tar.gz: commons-io-2.21.0-src/src/test/java/org/apache/commons/io/output/ClosedOutputStreamTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.io.output;

import static org.junit.jupiter.api.Assertions.assertThrows;

import java.io.IOException;

import org.junit.jupiter.api.Test;

/**
 * Tests {@link ClosedOutputStream}.
 */
class ClosedOutputStreamTest {

    /**
     * Test the {@code flush()} method.
     */
    @Test
    void testFlush() throws IOException {
        try (ClosedOutputStream cos = new ClosedOutputStream()) {
            assertThrows(IOException.class, cos::flush);
        }
    }

    @Test
    void testSingleton() throws IOException {
        try (@SuppressWarnings("deprecation")
        ClosedOutputStream cos = ClosedOutputStream.CLOSED_OUTPUT_STREAM) {
            assertThrows(IOException.class, cos::flush);
        }
        try (ClosedOutputStream cos = ClosedOutputStream.INSTANCE) {
            assertThrows(IOException.class, cos::flush);
        }
    }

    /**
     * Test the {@code write(b)} method.
     */
    @Test
    void testWrite() throws IOException {
        try (ClosedOutputStream cos = new ClosedOutputStream()) {
            assertThrows(IOException.class, () -> cos.write('x'));
        }
    }

    @Test
    void testWriteArray() throws IOException {
        try (ClosedOutputStream cos = new ClosedOutputStream()) {
            assertThrows(IOException.class, () -> cos.write(new byte[0]));
            assertThrows(IOException.class, () -> cos.write(new byte[10]));
        }
    }

    @Test
    void testWriteArrayIndex() throws IOException {
        try (ClosedOutputStream cos = new ClosedOutputStream()) {
            assertThrows(IOException.class, () -> cos.write(new byte[0], 0, 0));
            assertThrows(IOException.class, () -> cos.write(new byte[10], 0, 1));
        }
    }

}
